import usefulltools.math as math
import usefulltools.file as file

class Math(math.Math):
  pass

class File(file.File):
  pass